==> haskell-broadcast-chan-0.2.1.2-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-broadcast-chan.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 broadcast-chan
version:              0.2.1.2
visibility:           public
id:                   broadcast-chan-0.2.1.2-f02PvATo7NKoyx3Lp7VKE
key:                  broadcast-chan-0.2.1.2-f02PvATo7NKoyx3Lp7VKE
license:              BSD-3-Clause
copyright:            Copyright © 2014-2021 Merijn Verstraaten
maintainer:           Merijn Verstraaten <merijn@inconsistent.nl>
author:               Merijn Verstraaten
homepage:             https://github.com/merijn/broadcast-chan
synopsis:
    Closable, fair, single-wakeup channel type that avoids 0
    reader space leaks.

description:
    __WARNING:__ While the code in this library should be fairly stable and
    production, the API is something I'\''m still working on. API changes will
    follow the PVP, but __expect__ breaking API changes in future versions!

    A closable, fair, single-wakeup channel that avoids the 0 reader space leak
    that @"Control.Concurrent.Chan"@ from base suffers from.

    The @Chan@ type from @"Control.Concurrent.Chan"@ consists of both a read
    and write end combined into a single value. This means there is always at
    least 1 read end for a @Chan@, which keeps any values written to it alive.
    This is a problem for applications/libraries that want to have a channel
    that can have zero listeners.

    Suppose we have an library that produces events and we want to let users
    register to receive events. If we use a channel and write all events to it,
    we would like to drop and garbage collect any events that take place when
    there are 0 listeners. The always present read end of @Chan@ from base
    makes this impossible. We end up with a @Chan@ that forever accumulates
    more and more events that will never get removed, resulting in a memory
    leak.

    @"BroadcastChan"@ splits channels into separate read and write ends. Any
    message written to a a channel with no existing read end is immediately
    dropped so it can be garbage collected. Once a read end is created, all
    messages written to the channel will be accessible to that read end.

    Once all read ends for a channel have disappeared and been garbage
    collected, the channel will return to dropping messages as soon as they are
    written.

    __Why should I use "BroadcastChan" over "Control.Concurrent.Chan"?__

    * @"BroadcastChan"@ is closable,

    * @"BroadcastChan"@ has no 0 reader space leak,

    * @"BroadcastChan"@ has comparable or better performance.

    __Why should I use "BroadcastChan" over various (closable) STM channels?__

    * @"BroadcastChan"@ is single-wakeup,

    * @"BroadcastChan"@ is fair,

    * @"BroadcastChan"@ performs better under contention.

category:             System
abi:                  68df3789b135e9a71848979503d2314f
exposed:              True
exposed-modules:
    BroadcastChan BroadcastChan.Extra BroadcastChan.Prelude
    BroadcastChan.Throw

hidden-modules:       BroadcastChan.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/broadcast-chan-0.2.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/broadcast-chan-0.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-broadcast-chan
hs-libraries:         HSbroadcast-chan-0.2.1.2-f02PvATo7NKoyx3Lp7VKE
depends:
    base-4.16.4.0 transformers-0.5.6.2
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:
    /usr/share/doc/haskell-broadcast-chan/html/broadcast-chan.haddock

haddock-html:         /usr/share/doc/haskell-broadcast-chan/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-broadcast-chan-0.2.1.2-4-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-broadcast-chan.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 broadcast-chan
version:              0.2.1.2
visibility:           public
id:                   broadcast-chan-0.2.1.2-EL2bp18GDj1Y8ziKOtHVF
key:                  broadcast-chan-0.2.1.2-EL2bp18GDj1Y8ziKOtHVF
license:              BSD-3-Clause
copyright:            Copyright © 2014-2021 Merijn Verstraaten
maintainer:           Merijn Verstraaten <merijn@inconsistent.nl>
author:               Merijn Verstraaten
homepage:             https://github.com/merijn/broadcast-chan
synopsis:
    Closable, fair, single-wakeup channel type that avoids 0
    reader space leaks.

description:
    __WARNING:__ While the code in this library should be fairly stable and
    production, the API is something I'\''m still working on. API changes will
    follow the PVP, but __expect__ breaking API changes in future versions!

    A closable, fair, single-wakeup channel that avoids the 0 reader space leak
    that @"Control.Concurrent.Chan"@ from base suffers from.

    The @Chan@ type from @"Control.Concurrent.Chan"@ consists of both a read
    and write end combined into a single value. This means there is always at
    least 1 read end for a @Chan@, which keeps any values written to it alive.
    This is a problem for applications/libraries that want to have a channel
    that can have zero listeners.

    Suppose we have an library that produces events and we want to let users
    register to receive events. If we use a channel and write all events to it,
    we would like to drop and garbage collect any events that take place when
    there are 0 listeners. The always present read end of @Chan@ from base
    makes this impossible. We end up with a @Chan@ that forever accumulates
    more and more events that will never get removed, resulting in a memory
    leak.

    @"BroadcastChan"@ splits channels into separate read and write ends. Any
    message written to a a channel with no existing read end is immediately
    dropped so it can be garbage collected. Once a read end is created, all
    messages written to the channel will be accessible to that read end.

    Once all read ends for a channel have disappeared and been garbage
    collected, the channel will return to dropping messages as soon as they are
    written.

    __Why should I use "BroadcastChan" over "Control.Concurrent.Chan"?__

    * @"BroadcastChan"@ is closable,

    * @"BroadcastChan"@ has no 0 reader space leak,

    * @"BroadcastChan"@ has comparable or better performance.

    __Why should I use "BroadcastChan" over various (closable) STM channels?__

    * @"BroadcastChan"@ is single-wakeup,

    * @"BroadcastChan"@ is fair,

    * @"BroadcastChan"@ performs better under contention.

category:             System
abi:                  7de5123743fe09198dc9383a380bf545
exposed:              True
exposed-modules:
    BroadcastChan BroadcastChan.Extra BroadcastChan.Prelude
    BroadcastChan.Throw

hidden-modules:       BroadcastChan.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/broadcast-chan-0.2.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/broadcast-chan-0.2.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/broadcast-chan-0.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-broadcast-chan
hs-libraries:         HSbroadcast-chan-0.2.1.2-EL2bp18GDj1Y8ziKOtHVF
depends:
    base-4.17.2.1 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-broadcast-chan/html/broadcast-chan.haddock

haddock-html:         /usr/share/doc/haskell-broadcast-chan/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
